==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/NONCONFORMITYTYPEEMRSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour NONCONFORMITYTYPEEMRSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="NONCONFORMITYTYPEEMRSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NONCONFORMITYTYPEEMRSID_Type", propOrder = {
    "nonconformitytypeid",
    "vmrscode"
})
public class NONCONFORMITYTYPEEMRSID_Type {

    @XmlElement(name = "NONCONFORMITYTYPEID", required = true)
    protected NONCONFORMITYTYPEID_Type nonconformitytypeid;
    @XmlElement(name = "VMRSCODE", required = true)
    protected VMRSCODE_Type vmrscode;

    /**
     * Obtient la valeur de la propriété nonconformitytypeid.
     * 
     * @return
     *     possible object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public NONCONFORMITYTYPEID_Type getNONCONFORMITYTYPEID() {
        return nonconformitytypeid;
    }

    /**
     * Définit la valeur de la propriété nonconformitytypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public void setNONCONFORMITYTYPEID(NONCONFORMITYTYPEID_Type value) {
        this.nonconformitytypeid = value;
    }

    /**
     * Obtient la valeur de la propriété vmrscode.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public VMRSCODE_Type getVMRSCODE() {
        return vmrscode;
    }

    /**
     * Définit la valeur de la propriété vmrscode.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public void setVMRSCODE(VMRSCODE_Type value) {
        this.vmrscode = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/NONCONFORMITYTYPEEMRSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for NONCONFORMITYTYPEEMRSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NONCONFORMITYTYPEEMRSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYTYPEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSCODE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NONCONFORMITYTYPEEMRSID_Type", propOrder = {
    "nonconformitytypeid",
    "vmrscode"
})
public class NONCONFORMITYTYPEEMRSID_Type {

    @XmlElement(name = "NONCONFORMITYTYPEID", required = true)
    protected NONCONFORMITYTYPEID_Type nonconformitytypeid;
    @XmlElement(name = "VMRSCODE", required = true)
    protected VMRSCODE_Type vmrscode;

    /**
     * Gets the value of the nonconformitytypeid property.
     * 
     * @return
     *     possible object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public NONCONFORMITYTYPEID_Type getNONCONFORMITYTYPEID() {
        return nonconformitytypeid;
    }

    /**
     * Sets the value of the nonconformitytypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link NONCONFORMITYTYPEID_Type }
     *     
     */
    public void setNONCONFORMITYTYPEID(NONCONFORMITYTYPEID_Type value) {
        this.nonconformitytypeid = value;
    }

    /**
     * Gets the value of the vmrscode property.
     * 
     * @return
     *     possible object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public VMRSCODE_Type getVMRSCODE() {
        return vmrscode;
    }

    /**
     * Sets the value of the vmrscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSCODE_Type }
     *     
     */
    public void setVMRSCODE(VMRSCODE_Type value) {
        this.vmrscode = value;
    }

}
